# -*- coding: iso-8859-1 -*-

# arthelp_install.py
#
# PRE/POST-Install script for AR-Tool Helpers
#

import sys
from distutils.sysconfig import get_python_lib
import os.path

# Get folder for packages; in general "<Python installation folder>\Lib\site-packages"
package_folder = get_python_lib()
# In general, the package folder will already be on the search path, but it is added now to the search path
# for safety (again). It does not matter, if the same path occurs more than once on the search path.
sys.path.append(package_folder)

if sys.argv[1] == '-install':
    # Installation
    # The script is run after(!) all files have been copied with argv[1] set to "-install"
    
    # Register the ActiveX Scripting Engine for safety; it does not matter, if it is already registered.
    # Normally this is done by running "<package folder>\win32comext\axscript\client\pyscript.py" from the command
    # line with no command line option, which is not a valid approach from within the current script. Therefore we
    # intend to use the "Register" method of "pyscript" directly which requires importing "pyscript" in advance.
    # Unfortunately, "win32comext" is not structured as package (whereas "axscript" is a package), so we have
    # to add the "win32comext" path to the search path before importing "pyscript".
    # Set argv[1] to empty string for safety
    sys.path.append(os.path.join(package_folder, 'win32comext'))
    import axscript.client.pyscript
    sys.argv[1] = ''
    axscript.client.pyscript.Register()

    # Register the pertinent COM servers
    import ar_tool.ArtHelp
    ar_tool.ArtHelp.Register()

    # Register the pertinent NT services
    import ar_tool.ArtUtilSv
    ar_tool.ArtUtilSv.Register()

    print 'Installation completed'
    
else:
    # Uninstallation
    # The script is run before(!) all files have been removed with argv[1] set to "-remove"

    # There is no need to Unregister the ActiveX Scripting Engine

    # Unregister the pertinent COM servers
    import ar_tool.ArtHelp
    ar_tool.ArtHelp.Unregister()

    # Unregister the pertinent NT services
    import ar_tool.ArtUtilSv
    ar_tool.ArtUtilSv.Unregister()
    
    print 'Deinstallation completed'
