from distutils.core      import setup
from distutils.sysconfig import get_python_lib
import os, re, sys

_ARTHELP_VERSION_FILE = 'arthelp.version.txt'     # Name of the AR-Tool Helpers package version text file

pjoin = os.path.join

lib_path = get_python_lib()

script_path  = os.path.dirname(os.path.normcase(sys.argv[0]))
version_file = file(pjoin(script_path, _ARTHELP_VERSION_FILE))
arh_version  = version_file.readline()
version_file.close()
reg_expr = re.compile(r'\n')
arh_version = reg_expr.sub('', arh_version)
if not arh_version:
    arh_version = 'unknown'

# lib_path is an absolute path; nevertheless the windows installer created later
# will not use it as an absolute path as specified, but relative to sys.prefix
# so convert lib_path to a relative path by stripping sys.prefix
sys_pref = re.escape('%s\\' % sys.prefix)
reg_expr = re.compile(sys_pref, re.IGNORECASE)
lib_path = reg_expr.sub('', lib_path)

setup(
            name             = 'AR-Tool-Helpers',
            version          = arh_version,
            license          = 'See license texts installed in target directories',
            description      = 'Python Helpers for the AR-Tool',
            long_description = 'Python packages as helpers for the AR-Tool',
            author           = 'U. Weber, authors of the ReportLab Toolkit resp. Tiny RML2PDF',
            author_email     = 'uweber@csc.com',
            url              = 'http://openreport.org, http://reportlab.org',

            packages = [ 
                'reportlab',
                'reportlab.graphics',
                'reportlab.graphics.charts',
                'reportlab.graphics.widgets',
                'reportlab.lib',
                'reportlab.pdfbase',
                'reportlab.pdfgen',
                'reportlab.platypus',
                'trml2pdf',
                'ar_tool',
                ],

            data_files = [
                (lib_path, [
                'arthelp.version.txt',
                ]),
                (pjoin(lib_path, 'reportlab'), [
                'reportlab/README',
                'reportlab/README_ART.TXT',
                'reportlab/license.txt',
                ]),
                (pjoin(lib_path, 'reportlab/fonts'), [
                'reportlab/fonts/00readme.txt',
                'reportlab/fonts/LeERC___.AFM',
                'reportlab/fonts/LeERC___.PFB',
                'reportlab/fonts/luxiserif.ttf',
                'reportlab/fonts/luxiserif_license.txt',
                'reportlab/fonts/rina.ttf',
                'reportlab/fonts/rina_license.txt',
                ]),
                (pjoin(lib_path, 'reportlab/lib'), [
                'reportlab/lib/hyphen.mashed',
                ]),
                (pjoin(lib_path, 'trml2pdf'), [
                'trml2pdf/README.txt',
                'trml2pdf/README_ART.TXT',
                'trml2pdf/COPYRIGHT.txt',
                'trml2pdf/LICENSE.txt',
                ]),
                ],

            ext_modules = [],

            scripts = [
                'arthelp_install.py',
                ],
    )
